summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorDejan Jovanović <dejan.jovanovic@gmail.com>2009-12-10 18:44:51 +0000
committerDejan Jovanović <dejan.jovanovic@gmail.com>2009-12-10 18:44:51 +0000
commitf79afa96e7e7176b974252dd05a9f7bdf70194e8 (patch)
treecb12c0a880f8fbb356516a86699b0063a7bb8981 /test
parent8b2d1d64b886db4cff74e2a7b1370841979001b2 (diff)
killing expr into node...
Diffstat (limited to 'test')
-rw-r--r--test/unit/expr/expr_black.h6
-rw-r--r--test/unit/expr/expr_white.h6
2 files changed, 6 insertions, 6 deletions
diff --git a/test/unit/expr/expr_black.h b/test/unit/expr/expr_black.h
index 5f1deee8a..ad70bec91 100644
--- a/test/unit/expr/expr_black.h
+++ b/test/unit/expr/expr_black.h
@@ -1,4 +1,4 @@
/* Black box testing of CVC4::Expr. */
#include <cxxtest/TestSuite.h>
@@ -10,10 +10,10 @@ class ExprBlack : public CxxTest::TestSuite {
public:
void testNull() {
- Expr::s_null;
+ Node::s_null;
}
void testCopyCtor() {
- Expr e(Expr::s_null);
+ Node e(Node::s_null);
}
};
@@ -1,4 +1,4 @@
-/* Black box testing of CVC4::Expr. */
+/* Black box testing of CVC4::Node. */
#include <cxxtest/TestSuite.h>
diff --git a/test/unit/expr/expr_white.h b/test/unit/expr/expr_white.h
index 3da360126..6b48d66e6 100644
--- a/test/unit/expr/expr_white.h
+++ b/test/unit/expr/expr_white.h
@@ -1,4 +1,4 @@
/* White box testing of CVC4::Expr. */
#include <cxxtest/TestSuite.h>
@@ -10,10 +10,10 @@ class ExprWhite : public CxxTest::TestSuite {
public:
void testNull() {
- Expr::s_null;
+ Node::s_null;
}
void testCopyCtor() {
- Expr e(Expr::s_null);
+ Node e(Node::s_null);
}
};
generated by cgit on debian on lair
@@ -1,4 +1,4 @@
-/* White box testing of CVC4::Expr. */
+/* White box testing of CVC4::Node. */
#include <cxxtest/TestSuite.h>
contact matthew@masot.net with questions or feedback